#ifndef _SQLITE3JSON_H
#define _SQLITE3JSON_H

#include <sqlite3.h>

/*
 * Function to print one character, similar to fputc(3)
 */

typedef void (putfunc)(int c, void *arg);

/*
 * Execute SQL sending JSON result using print function pointer
 *
 * Layout of JSON result:
 *
 *  object {results, sql}
 *   results[] object {columns, rows, changes, last_insert_rowid, error}
 *    columns[]
 *     object {name, decltype, type }     (sqlite3_column_*)
 *    rows[][]                            (sqlite3_column_*)
 *    changes                             (sqlite3_changes)
 *    last_insert_rowid                   (sqlite3_last_insert_rowid)
 *    error                               (sqlite3_errmsg)
 *   sql                                  (SQL text)
 *
 *  For each single SQL statement in "sql" an object in the "results"
 *  array is produced.
 *
 * Arguments:
 *   db      handle to open SQLite3 database
 *   sql     query(ies) to be executed by sqlite3_prepare et.al.
 *   pfunc   function pointer to char output function
 *   arg     handle for pfunc
 *
 * Result:
 *   SQLite error code, see sqlite3.h
 */

int sqlite3json(sqlite3 *db, const char *sql, putfunc *pfunc, void *arg);

#endif

